@@ -105,20 +105,20 @@ def install_issues(check_nlp = True):
   ret = []
   FNULL = open(os.devnull, 'w') 
   if shutil.which("R") is None:
-    ret.append["Cannot find R language. Please installe it. PANDEM2 needs it to calculate indecators"]
+    ret.append("Cannot find R language. Please installe it. PANDEM2 needs it to calculate indecators")
   else:
     r_packages = '"dplyr", "shiny", "plotly", "DT", "jsonlite", "httr", "XML", "ggplot2"'
     installed = subprocess.run(['R', '-e', f'if(length(setdiff(c({r_packages}), names(installed.packages()[,1])))> 0) stop("some packages are missing!!")'], stdout=FNULL, stderr=FNULL).returncode
     if installed == 1:
       ret.append(f'Cannot find some necessary R packages, please intall them from CRAN, by running install.packages(c({r_packages}))')
-    installed = subprocess.run(['R', '-e', f'if(length(setdiff(c(), names(installed.packages("COVID19")[,1])))> 0) stop("some packages are missing!!")'], stdout=FNULL, stderr=FNULL).returncode
+    installed = subprocess.run(['R', '-e', f'if(length(setdiff(c("COVID19"), names(installed.packages()[,1])))> 0) stop("some packages are missing!!")'], stdout=FNULL, stderr=FNULL).returncode
     if installed == 1:
       ret.append(f"""Cannot find COVID19 R packages necessary for getting COVID19 data hub data. 
       if you want to download data directly from sources you have to install it as follow:
         install.packages("devtools")
         devtools::install_github(repo = "covid19datahub/COVID19", ref = "b941b66e59b7b0aec4807eb5b28208abba66de4a", upgrade = "never")
       If you prefer downloading data prepared by COVID data hub tem you can install it from CRAN, by running install.packages(c("COVID19"))""")
-    installed = subprocess.run(['R', '-e', f'if(length(setdiff(c(), names(installed.packages("Pandem2simulator")[,1])))> 0) stop("some packages are missing!!")'], stdout=FNULL, stderr=FNULL).returncode
+    installed = subprocess.run(['R', '-e', f'if(length(setdiff(c("Pandem2simulator"), names(installed.packages()[,1])))> 0) stop("some packages are missing!!")'], stdout=FNULL, stderr=FNULL).returncode
     if installed == 1:
       ret.append(f"""Cannot find Pandem2simulator R packages necessary for simulating COVID19 detailed data from ecdc datasets. 
       You can install this package with the following command:
@@ -132,7 +132,7 @@ def install_issues(check_nlp = True):
        if not nlp_models_up():
          # Here if it will be to pandem2 to launch docker since models are not up   
          if shutil.which("docker") is None:
-           ret.append["Cannot find docker and NLP models are not running, we need it to start the NLP server. Please install it."]
+           ret.append("Cannot find docker and NLP models are not running, we need it to start the NLP server. Please install it.")
          else:
            l.info("Launching docker for serving NLP modles")
            retries = 10
