@@ -359,13 +359,13 @@ class Pipeline(worker.Worker):
     
     # this function returns a future that can be waited to ensure that file job is written to disk
     def update_job_step(self, job, step, progress):
-        l.debug(f"Changing to step {step} for job {job['id']} source {job['dls_json']['scope']['source']} {round(progress*100, 1)}%")
+        l.debug(f"Changing to step {step} for job {int(job['id'])} source {job['dls_json']['scope']['source']} {round(progress*100, 1)}%")
         # removing job from current step dict
         if job["step"] in self.job_steps and job["id"]:
           if job["id"] in self.job_steps[job["step"]]:
             self.job_steps[job["step"]].pop(job["id"])
           else:
-            l.warning(f"Warning: could not find id {job['id']} in job_steps {job['step']}") 
+            l.warning(f"Warning: could not find id {int(job['id'])} in job_steps {job['step']}") 
         # changing the job step 
         job["step"] = step
         job["progress"] = progress
